@@ -65,10 +65,13 @@
 		Solucionamos la codificacin de los ttulos de un marcador para que acepte caracteres especiales (Yu Jianrong)
 	Version 1.4
 		Convertimos las llamadas XMLHttpRequests en asincronas
+		Eliminamos la variable isContextOpen
+		Creamos la variable gRequestObserver
+	Versin 1.5 
+		Gestin de las llamadas asncronas
+		Cambiamos la ordenacin del carpetas y marcadores para que no distinga entre maysculas y minsculas
 */
 
-var isContextOpen = false;
-
 var dengGB = {
 	defaultSep: "_SEP_",
 	m_labelsArr: null,
@@ -267,7 +270,6 @@ var dengGB = {
 	// Men contextual de un marcador
 	onBookmarkContextMenu: function(event) {
 		try {
-			isContextOpen = true;
 			dengGB.currentContextId = event.target.getAttribute("id");
 			
 			document.getElementById("bookmarkContext").showPopup(document.getElementById(dengGB.currentContextId), 
@@ -278,7 +280,13 @@ var dengGB = {
 		}
 	},
 	sortBookmarks: function (a, b) {
-		return a.getElementsByTagName("title")[0].childNodes[0].nodeValue < b.getElementsByTagName("title")[0].childNodes[0].nodeValue ? -1 : 1; 
+		return a.getElementsByTagName("title")[0].childNodes[0].nodeValue.toLowerCase() < b.getElementsByTagName("title")[0].childNodes[0].nodeValue.toLowerCase() ? -1 : 1; 
+	},
+	sortStrings: function (a, b) {
+		var aStr = new String(a);
+		var bStr = new String(b);
+	
+		return aStr.toLowerCase() < bStr.toLowerCase() ? -1 : 1; 
 	},
 	// Marcadores y subcarpetas de una carpeta
 	popupPopulate: function(e, label) {
@@ -330,7 +338,7 @@ var dengGB = {
 				}
 			}
 				
-			subfoldersLabelsArr.sort();
+			subfoldersLabelsArr.sort(dengGB.sortStrings); 
 			bookmarksArr.sort(dengGB.sortBookmarks);
 
 			// Aadimos las subcarpetas que haya
@@ -511,11 +519,34 @@ var dengGB = {
 			var httpRequest = new XMLHttpRequest();
 
 			// Creamos una funcin asincrona
-			httpRequest.onreadystatechange = function() {
-				if (httpRequest.status == 200) dengGB.m_response = httpRequest.responseXML.documentElement;
-			}
-			
-			httpRequest.open("GET", "http://www.google.com/bookmarks/lookup?output=xml&num=10000", false); 
+			httpRequest.open("GET", "http://www.google.com/bookmarks/lookup?output=xml&num=10000", true); 
+			httpRequest.onreadystatechange = function(aEvt) {
+				if (httpRequest.readyState == 4 && httpRequest.status == 200) dengGB.m_response = httpRequest.responseXML.documentElement;
+			};
+			httpRequest.send(null);
+		}
+		catch (ex) {
+			dengGB.dumpDebug("requestBookmarks", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + ex);
+		}
+	},
+	// Volvemos a pedir los marcadores a Google
+	requestBookmarksEx: function(funct) {
+		try {
+			dengGB.m_response = null;
+
+			var httpRequest = new XMLHttpRequest();
+
+			// Creamos una funcin asincrona
+			httpRequest.open("GET", "http://www.google.com/bookmarks/lookup?output=xml&num=10000", true); 
+			httpRequest.onreadystatechange = function(aEvt) {
+				if (httpRequest.readyState == 4 && httpRequest.status == 200) {
+					dengGB.m_response = httpRequest.responseXML.documentElement;
+					
+					if (funct == "createMenuAsynchronous") {
+						dengGB.createMenuAsynchronous();
+					}
+				}
+			};
 			httpRequest.send(null);
 		}
 		catch (ex) {
@@ -632,11 +663,10 @@ var dengGB = {
 						var httpRequest = new XMLHttpRequest();
 						
 						// Creamos una funcin asincrona
-						httpRequest.onreadystatechange = function() {
-							if (httpRequest.status == 200) dengGB.restoreUserAgent();
-						}
-						
-						httpRequest.open("POST", "http://www.google.com/bookmarks/mark", false); 
+						httpRequest.open("POST", "http://www.google.com/bookmarks/mark", true); 
+						httpRequest.onreadystatechange = function(aEvt) {
+							if (httpRequest.readyState == 4 && httpRequest.status == 200) dengGB.restoreUserAgent();
+						};
 						httpRequest.send('q=' + escape(url) + '&title=' + encodeURI(ds) + '&labels=' + encodeURI(tag));
 					}
 					
@@ -837,7 +867,7 @@ var dengGB = {
 					}
 				}
 			}
-			subfoldersArr.sort();
+			subfoldersArr.sort(dengGB.sortStrings);
 			childrenArr.sort(dengGB.sortBookmarks);
 		}
 		catch (ex) {
@@ -1039,7 +1069,7 @@ var dengGB = {
 				}
 					
 				// Ordenamos el array
-				noTagBookmarks.sort();
+				noTagBookmarks.sort(dengGB.sortStrings);
 					
 				for (i = 0; i < numNoTagBookmarks; i++) {
 					dengGB.insertBookmarksTreeElement(rootTreeChildren, 
@@ -1137,28 +1167,27 @@ var dengGB = {
 			// Hay que eliminar el marcador anterior?
 			if (retVals.id != "") dengGB.removeBookmark(e, retVals.id, false, false); 
 			
-			dengGB.updateStatusPanel(document.getElementById("dengGB.strings").getString("dengGB.RequestAddBookmark"));
-			dengGB.setWaitCursor(true);
+			if (document.getElementById("dengGBToolbarButton")) 
+				document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/refresh.png";
 			
 			dengGB.overrideUserAgent();
 
 			// Insertamos el nuevo marcador usando una llamada asncrona
 			var httpRequest = new XMLHttpRequest();
 			
-			// Creamos una funcin asincrona
-			httpRequest.onreadystatechange = function() {
-				if (httpRequest.status == 200) {
-					dengGB.updateStatusPanel(document.getElementById("dengGB.strings").getString("dengGB.BookmarkAdded"));
-					dengGB.setWaitCursor(false);
-					
-					// refrescamos nuestros marcadores
-					retVals.mainObj.refreshBookmarks(e);
-					
+			// Creamos una funcin asincrona, no nos importa la respuesta
+			httpRequest.open("POST", "http://www.google.com/bookmarks/mark", true); 
+			httpRequest.onreadystatechange = function(aEvt) {
+				if (httpRequest.readyState == 4 && httpRequest.status == 200) {
+					// AQUI NO ENTRA EL CDIGO!!!!!!!!!!!!!!: SEGURAMENTE PORQUE EL DILOGO EST EN PANTALLA????????????
 					dengGB.restoreUserAgent();
+					dengGB.refreshBookmarks(e);
+					if (document.getElementById("dengGBToolbarButton")) 
+						document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/dengGB.png";
 				}
-			}
-
-			httpRequest.open("POST", "http://www.google.com/bookmarks/mark", false); 
+			};
+			dengGB.setBookmarkReload(true); // Forzamos una reconstruccin del men la prxima vez XXXXXXXXXXXXXXX
+			//dengGB.callPreferencesDialog();			
 			httpRequest.send('q=' + escape(retVals.url) + '&title=' + encodeURI(retVals.ds) + '&labels=' + encodeURI(retVals.tag));
 		}
 		catch (ex) {
@@ -1166,6 +1195,46 @@ var dengGB = {
 		}
 		return true;
 	},
+	// Eliminar marcadores
+	// Unbookmark: http://www.google.com/bookmarks/mark?dlq={IDENTIFICADOR}&sig={KEY}
+	removeBookmark: function (e, _id, askFirst, refresh) {
+		// Pedimos confirmacin
+		if (askFirst) {
+			var bS = { id: _id, label: "", url: "", tag: "" };
+			
+			dengGB.getBookmarkFromId(bS);
+			
+			var result = this.promptService.confirm(window, 
+				document.getElementById("dengGB.strings").getString("dengGB.RemoveAsBookmark"), 
+				document.getElementById("dengGB.strings").getString("dengGB.RemoveBookmarkConfirm") + " '" + bS.label + "'?");
+				
+			if (!result) return;
+		}
+			
+		try {
+			if (document.getElementById("dengGBToolbarButton")) 
+				document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/refresh.png";
+			// Eliminamos el marcador
+			dengGB.overrideUserAgent();
+				
+			var httpRequest = new XMLHttpRequest();
+			
+			// Creamos una funcin asincrona, no nos importa la respuesta
+			httpRequest.open("POST", "http://www.google.com/bookmarks/mark", true); 
+			httpRequest.onreadystatechange = function(aEvt) {
+				if (httpRequest.readyState == 4 && httpRequest.status == 200) {
+					dengGB.restoreUserAgent();
+					dengGB.refreshBookmarks(e);
+					if (document.getElementById("dengGBToolbarButton")) 
+						document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/dengGB.png";
+				}
+			};
+			httpRequest.send('dlq=' + escape(_id)); 
+		}
+		catch (ex) {
+			dengGB.dumpDebug("removeBookmark", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + ex);
+		}
+	},
 	getBookmarkFromId: function(bS) {
 		try {
 			var bookmarks = dengGB.m_response.getElementsByTagName("bookmark");
@@ -1190,67 +1259,27 @@ var dengGB = {
 			dengGB.dumpDebug("getBookmarkFromId", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + ex);
 		}
 	},
-	// Eliminar marcadores
-	// Unbookmark: http://www.google.com/bookmarks/mark?dlq={IDENTIFICADOR}&sig={KEY}
-	removeBookmark: function (e, _id, askFirst, refresh) {
-		try {
-			// Pedimos confirmacin
-			if (askFirst) {
-				var bS = { id: _id, label: "", url: "", tag: "" };
-				
-				dengGB.getBookmarkFromId(bS);
-				
-				var result = this.promptService.confirm(window, 
-					document.getElementById("dengGB.strings").getString("dengGB.RemoveAsBookmark"), 
-					document.getElementById("dengGB.strings").getString("dengGB.RemoveBookmarkConfirm") + " '" + bS.label + "'?");
-					
-				if (!result) return;
-			}
-		}
-		catch (ex) {
-			dengGB.dumpDebug("[0] removeBookmark", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + ex);
-		}
-			
-		if (document.getElementById("dengGBToolbarButton")) document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/refresh.png";
-		try {
-			// Eliminamos el marcador
-			dengGB.updateStatusPanel(document.getElementById("dengGB.strings").getString("dengGB.RequestRemoveBookmark"));
-			
-			dengGB.overrideUserAgent();
-				
-			var httpRequest = new XMLHttpRequest();
-			
-			// Creamos una funcin asincrona
-			httpRequest.onreadystatechange = function() {
-				if (httpRequest.status == 200) {
-					dengGB.restoreUserAgent();
-					
-					dengGB.updateStatusPanel(document.getElementById("dengGB.strings").getString("dengGB.BookmarkRemoved"));
-					// No refrescamos nuestros marcadores si venimos de 'editBookmark'
-					if (refresh) dengGB.refreshBookmarks(e);
-				}
-			}
-			
-			httpRequest.open("POST", "http://www.google.com/bookmarks/mark", false); 
-			httpRequest.send('dlq=' + escape(_id)); 
-		}
-		catch (ex) {
-			dengGB.dumpDebug("removeBookmark", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + ex);
-		}
-		if (document.getElementById("dengGBToolbarButton")) document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/dengGB.png";
-	},
 	// Pedimos los bookmarks a Google
 	getBookmarksFromGoogleAndCreateMenu: function() {
-		document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/refresh.png";
+		try {
+			if (document.getElementById("dengGBToolbarButton"))
+				document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/refresh.png";
+		
+			// Lanzamos la peticin de los marcadores asincrona		
+			dengGB.requestBookmarksEx("createMenuAsynchronous");
+		}
+		catch (e) {
+			dengGB.dumpDebug("getBookmarksFromGoogleAndCreateMenu", document.getElementById("dengGB.strings").getString("dengGB.RetrieveBookmarksGeneralError") + e);
+		}
+	},
+	// Invocamos este mtodo despues de requestBookmarksEx
+	createMenuAsynchronous: function() {
 		try {
 			var dengGBMainMenuPopup = document.getElementById('dengGBMainMenuPopup');
 			var dengGBSeparator = document.getElementById('separatorAbout');
 			var tempStr = "";
 			var defaultBookmarksSep = dengGB.getBookmarksLevelSeparator();
-			
-			// Lanzamos la peticin de los marcadores		
-			dengGB.requestBookmarks();
-				
+
 			// Primero buscamos cuantas etiquetas distintas hay. Eliminamos las que empiezan por ^
 			var labels = dengGB.m_response.getElementsByTagName("label");
 			var bookmarks = dengGB.m_response.getElementsByTagName("bookmark");
@@ -1283,7 +1312,7 @@ var dengGB = {
 				dengGB.m_labelsArr = strLabels.split(dengGB.defaultSep);
 				
 				// Ordenamos el array
-				dengGB.m_labelsArr.sort();
+				dengGB.m_labelsArr.sort(dengGB.sortStrings); // Cambiamos la ordenacin de carpetas para que no distinga entre maysculas y minsculas
 				
 				for (i = 0; i < dengGB.m_labelsArr.length; i++) {
 					// Creamos un menupopup
@@ -1333,7 +1362,7 @@ var dengGB = {
 				}
 				
 				// Ordenamos el array
-				noTagBookmarks.sort();
+				noTagBookmarks.sort(dengGB.sortStrings);
 				
 				for (i = 0; i < numNoTagBookmarks; i++) {
 					var mItem = document.createElement("menuitem");
@@ -1351,11 +1380,12 @@ var dengGB = {
 					dengGB.getFavicon(dengGBMainMenuPopup.insertBefore(mItem, dengGBSeparator), noTagBookmarks[i][2], "image");
 				}
 			}
+			dengGB.addRemoveMenuItem();
+			if (document.getElementById("dengGBToolbarButton")) document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/denggb.png";
 		}
 		catch (e) {
 			dengGB.dumpDebug("getBookmarksFromGoogleAndCreateMenu", document.getElementById("dengGB.strings").getString("dengGB.RetrieveBookmarksGeneralError") + e);
 		}
-		document.getElementById("dengGBToolbarButton").image = "chrome://dengGB/skin/denggb.png";
 	},
 	removeMenuItems: function() {
 		try {
@@ -1399,7 +1429,6 @@ var dengGB = {
 	},
 	// Actualizamos los bookmarks
 	refreshBookmarks: function (e) {
-		dengGB.updateStatusPanel(document.getElementById("dengGB.strings").getString("dengGB.RetrieveBookmarks"));
 		try {
 			dengGB.removeMenuItems();
 			// Volvemos a solicitar los marcadores y a crear los menus
@@ -1409,11 +1438,12 @@ var dengGB = {
 		catch (ex) {
 			dengGB.dumpDebug("refreshBookmarks", document.getElementById("dengGB.strings").getString("error") + ex);
 		}
-		dengGB.updateStatusPanel("");
 	},
 	// Ponemos el elemento para aadir o eliminar un marcador en funcin de la pgina que haya en pantalla
 	addRemoveMenuItem: function() {
 		try {
+			if (dengGB.m_response == null) return;
+		
 			var dengGBMainMenuPopup 	= document.getElementById('dengGBMainMenuPopup');
 			var currUrl 				= window.top._content.location.href.toLowerCase();
 			var currUrlIsInBookmarks 	= false;
@@ -1456,12 +1486,19 @@ var dengGB = {
 	},	
 	// Mostrar el menu de dengGB
 	onpopupshowing: function(e) {
-		dengGB.getBookmarksLevelSeparator(); // Pedimos/establecemos el separador por defecto
-		
 		try {
 			var dengGBMainMenuPopup = document.getElementById('dengGBMainMenuPopup');
 			var dengGBSeparator 	= document.getElementById('separatorAbout');
-			
+
+			dengGB.getBookmarksLevelSeparator(); // Pedimos/establecemos el separador por defecto
+
+			if (dengGB.getBookmarkReload()) {
+				dengGB.removeMenuItems();
+				// Volvemos a solicitar los marcadores y a crear los menus
+				dengGB.m_response = null;
+				dengGB.setBookmarkReload(false);
+			}
+
 			// Est conectado?
 			if (dengGB.checkLogin()) {
 				// Si el separador por defecto, o la opcin de mostrar iconos, ha cambiado volvemos a pedir el men
@@ -1479,13 +1516,13 @@ var dengGB = {
 				// Si ya hemos creado el menu solo gestionamos el icono de aadir o eliminar marcador
 				if (document.getElementById("googleManageBookmarks")) {
 					dengGB.addRemoveMenuItem();
-					return; 
+					return true;  	// Mostramos el men
 				}
 					
 				// Si el menu de conectarse esta creado, lo eliminamos
 				var googleConnect = document.getElementById('googleConnect');
 					
-				if (googleConnect) dengGBMainMenuPopup.removeChild(googleConnect);
+				if (googleConnect && dengGBMainMenuPopup) dengGBMainMenuPopup.removeChild(googleConnect);
 					
 				// Aadimos un menu para gestionar los marcadores
 				var mItem = document.createElement("menuitem");
@@ -1499,12 +1536,14 @@ var dengGB = {
 					setAttribute("oncommand", "dengGB.onManageBookmarks(event);");
 				}
 					
-				if (document.getElementById("addBookmark"))
-					dengGBMainMenuPopup.insertBefore(mItem, document.getElementById("addBookmark"));
-				else if (document.getElementById("removeBookmark"))
-					dengGBMainMenuPopup.insertBefore(mItem, document.getElementById("removeBookmark"));
-				else
-					dengGBMainMenuPopup.insertBefore(mItem, dengGBSeparator);
+				if (dengGBMainMenuPopup) {
+					if (document.getElementById("addBookmark"))
+						dengGBMainMenuPopup.insertBefore(mItem, document.getElementById("addBookmark"));
+					else if (document.getElementById("removeBookmark"))
+						dengGBMainMenuPopup.insertBefore(mItem, document.getElementById("removeBookmark"));
+					else
+						dengGBMainMenuPopup.insertBefore(mItem, dengGBSeparator);
+				}
 					
 				// Creamos una opcin de men para 'gestionar' los marcadores
 				var mItemManage = document.createElement("menuitem");
@@ -1517,16 +1556,12 @@ var dengGB = {
 					setAttribute("tooltiptext", document.getElementById("dengGB.strings").getString("dengGB.LocalManageBookmarks.tooltiptext"));
 					setAttribute("oncommand", "dengGB.onLocalManageBookmarks(event);");
 				}
-				dengGBMainMenuPopup.insertBefore(mItemManage, mItem);
-					
-				// Pedimos los bookmarks
-				dengGB.updateStatusPanel(document.getElementById("dengGB.strings").getString("dengGB.RetrieveBookmarks"));
-				dengGB.getBookmarksFromGoogleAndCreateMenu();
+				if (dengGBMainMenuPopup) dengGBMainMenuPopup.insertBefore(mItemManage, mItem);
 					
 				// Aadimos la opcin de Refresh. Si ya existe lo eliminamos
 				var refreshBookmarksItem = document.getElementById("refreshBookmarks");
 					
-				if (refreshBookmarksItem) dengGBMainMenuPopup.removeChild(refreshBookmarksItem);
+				if (refreshBookmarksItem && dengGBMainMenuPopup) dengGBMainMenuPopup.removeChild(refreshBookmarksItem);
 					
 				var mItemRefresh = document.createElement("menuitem");
 				with (mItemRefresh) {
@@ -1537,14 +1572,15 @@ var dengGB = {
 					setAttribute('image', "chrome://dengGB/skin/refresh.png");
 					setAttribute('oncommand', "dengGB.refreshBookmarks(event)");
 				}
-				dengGBMainMenuPopup.insertBefore(mItemRefresh, 
-					document.getElementById("firstSeparator") ? document.getElementById("firstSeparator") : dengGBSeparator);
-
-				// Existe ya el elemento de aadir / eliminar?
-				dengGB.addRemoveMenuItem();
+				if (dengGBMainMenuPopup) 
+					dengGBMainMenuPopup.insertBefore(mItemRefresh, 
+						document.getElementById("firstSeparator") ? document.getElementById("firstSeparator") : dengGBSeparator);
+						
+				// Llamada asncrona para pedir los bookmarks
+				dengGB.getBookmarksFromGoogleAndCreateMenu(); 
 			}
 			else {
-				// No estamos comectados a Google: aadimos un men para pedir usuario y contrasea
+				// No estamos conectados a Google: aadimos un men para pedir usuario y contrasea
 				dengGB.removeMenuItems(); // Primero eliminamos los menus si es que existen
 				if (!document.getElementById("googleConnect")) { // Si est creado ya, nos vamos
 					var mItem = document.createElement("menuitem");
@@ -1559,11 +1595,13 @@ var dengGB = {
 					document.getElementById("dengGBMainMenuPopup").insertBefore(mItem, document.getElementById("separatorAbout"));
 				}
 			}
+			// Aadimos el menu para eliminar/aadir marcador
+			dengGB.addRemoveMenuItem();
 		}
 		catch(e) {
 			dengGB.dumpDebug("onpopupshowing", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + e);
 		}
-		dengGB.updateStatusPanel("");
+		return true;  	// Mostramos el men
 	},
 	// Recuperamos el separador 
 	getBookmarksLevelSeparator: function() {
@@ -1574,10 +1612,41 @@ var dengGB = {
 			sep = prefs.getCharPref("dengGB.bookmarkSeparator");
 		else {
 			prefs.setCharPref("dengGB.bookmarkSeparator", "/");
-			sep = "/"
+			sep = "/";
 		}
 		return sep;
 	},
+	// Forzamos refresco?
+	getBookmarkReload: function() {
+		try {
+			var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);	
+			var value;
+			
+			if (prefs.getPrefType("dengGB.bookmarkReload") == prefs.PREF_BOOL)
+				value = prefs.getBoolPref("dengGB.bookmarkReload");
+			else {
+				prefs.setBoolPref("dengGB.bookmarkReload", false);
+				value = false;
+			}
+			return value;
+		}
+		catch(e) {
+			dengGB.dumpDebug("getBookmarkReload", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + e);
+		}
+		return false;
+	},
+	setBookmarkReload: function(value) {
+		try {
+			var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);	
+			
+			prefs.setBoolPref("dengGB.bookmarkReload", value);
+			return true;
+		}
+		catch(e) {
+			dengGB.dumpDebug("setBookmarkReload", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + e);
+		}
+		return false;
+	},
 	// Queremos recuperar los favicons?
 	getFavIconsOption: function() {
 		try {
@@ -1597,9 +1666,6 @@ var dengGB = {
 		}
 		return false;
 	},
-	updateStatusPanel: function(msg) {
-		if (document.getElementById("dengGBPanel")) document.getElementById("dengGBPanel").label = msg;
-	},
 	setWaitCursor: function(state) {
 		try {
 			if (state)
@@ -1608,7 +1674,6 @@ var dengGB = {
 				setCursor("default");
 		}
 		catch(e) {
-			dengGB.dumpDebug("setWaitCursor", document.getElementById("dengGB.strings").getString("dengGB.ExceptionError") + e);
 		}
 	},
 	callPreferencesDialog: function() {
@@ -1655,7 +1720,7 @@ var dengGB = {
 									.createInstance().QueryInterface(Components.interfaces.nsIURIChecker);
 				// uri creation needs to be localized
 				uriChecker.init(imageUri);
-				uriChecker.asyncCheck(new imageRequestObserver(item, dstField), null);
+				uriChecker.asyncCheck(gRequestObserver, null);
 				
 				item.setAttribute(dstField, uriLink.scheme + "://" + uriLink.host + "/favicon.ico");
 			}
@@ -1667,21 +1732,11 @@ var dengGB = {
 	}
 };
 
-function  imageRequestObserver (item, dstField) {
-	this.item = item;
-	this.dstField = dstField;
-}
-
-imageRequestObserver.prototype = {
-	// La interfaz urichecker exije que definamos OnStartRequest a pesar de que no la usemos
-	onStartRequest: function(request, ctxt) { },
-
-	// Preguntamos por el estatus de la peticin
+var gRequestObserver = {
 	onStopRequest: function(request, ctxt, status) {
 		// Si no encontramos el icono ponemos uno por defecto
 		if (status != 0) this.item.setAttribute(this.dstField, "chrome://dengGB/skin/bookmark.png");
 	}
-}
+};
 
 window.addEventListener("load", function(e) { dengGB.onLoad(e); }, false);
-window.addEventListener("click", function(e) { if (isContextOpen && e.button == 0) document.getElementById("dengGBMainMenuPopup").hidePopup(); isContextOpen = false;}, false);
